import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * A simple GUI to hold and control a painting Painter.
 */
public class PainterGUI implements ActionListener
{
    private Painter painter;
    private JButton strokeButton;
    private JButton colorButton;
    private JButton eraseButton;

    /**
     * Creates a new PainterFrame object
     */
    public PainterGUI()
    {
        JFrame frame = new JFrame("JavaPaint");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);     
        frame.setResizable(false);

        frame.setLayout(new BorderLayout());

        painter = new Painter(); //the painting panel
        frame.add(painter, BorderLayout.CENTER);

        //buttons for the panel
        colorButton = new JButton("Set Color");
        colorButton.addActionListener(this);
        strokeButton = new JButton("Set Stroke");
        strokeButton.addActionListener(this);
        eraseButton = new JButton("Erase All");
        eraseButton.addActionListener(this);        
        JPanel buttonPanel = new JPanel(new GridLayout(1,3));
        buttonPanel.add(colorButton);
        buttonPanel.add(strokeButton);
        buttonPanel.add(eraseButton);
        frame.add(buttonPanel,BorderLayout.SOUTH);

        frame.pack();
        frame.setVisible(true);
    }

    //responds to actionEvents (buttons)
    public void actionPerformed(ActionEvent evt)
    {
        if(evt.getSource() == eraseButton)
        {
            painter.eraseAll();
        }
        else if(evt.getSource() == colorButton)
        {
            Color c = JColorChooser.showDialog(null, "Pick a color", Color.BLACK);
            if(c != null)
            {
                painter.setPaintColor(c);
            }
        }
        else if(evt.getSource() == strokeButton)
        {
            String input = JOptionPane.showInputDialog("Enter a stroke width (in pixels)");
            try //in case something goes wrong (we got a bad value)
            {
                painter.setBrushSize(Float.parseFloat(input));
            }
            catch(NumberFormatException e)
            {
                //we just won't change anything if they type in a bad value
            }
        }
    }
}
